Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5596)

Unified Diff: chrome/test/data/webui/settings/import_data_dialog_test.js

Issue 2727813002: Options/MD Settings: use new prefs to drive import data dialog (Closed)
Patch Set: pastarmovj@ review Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/data/policy/policy_test_cases.json ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/data/webui/settings/import_data_dialog_test.js
diff --git a/chrome/test/data/webui/settings/import_data_dialog_test.js b/chrome/test/data/webui/settings/import_data_dialog_test.js
index d053879752555a9328736123f3613e9e617af045..66c62207ddccc046e3eb8732fa6390fa148a1f8b 100644
--- a/chrome/test/data/webui/settings/import_data_dialog_test.js
+++ b/chrome/test/data/webui/settings/import_data_dialog_test.js
@@ -75,12 +75,9 @@ suite('ImportDataDialog', function() {
}
var prefs = {};
- [
- 'import_history',
- 'import_bookmarks',
- 'import_saved_passwords',
- 'import_search_engine',
- 'import_autofill_form_data',
+ ['import_dialog_history', 'import_dialog_bookmarks',
+ 'import_dialog_saved_passwords', 'import_dialog_search_engine',
+ 'import_dialog_autofill_form_data',
].forEach(function(name) {
prefs[name] = createBooleanPref(name);
});
@@ -128,11 +125,11 @@ suite('ImportDataDialog', function() {
simulateBrowserProfileChange(1);
assertTrue(dialog.$.import.disabled);
- // Ensure everything except |import_bookmarks| is ignored.
- dialog.set('prefs.import_history.value', true);
+ // Ensure everything except |import_dialog_bookmarks| is ignored.
+ dialog.set('prefs.import_dialog_history.value', true);
assertTrue(dialog.$.import.disabled);
- dialog.set('prefs.import_bookmarks.value', true);
+ dialog.set('prefs.import_dialog_bookmarks.value', true);
assertFalse(dialog.$.import.disabled);
});
@@ -175,7 +172,7 @@ suite('ImportDataDialog', function() {
});
test('ImportFromBrowserProfile', function() {
- dialog.set('prefs.import_bookmarks.value', false);
+ dialog.set('prefs.import_dialog_bookmarks.value', false);
var expectedIndex = 0;
simulateBrowserProfileChange(expectedIndex);
« no previous file with comments | « chrome/test/data/policy/policy_test_cases.json ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698